# [Zope-tests] OK : Zope Buildbot / zope2.13-py2.6 slave-osx

jdriessen at thehealthagency.com jdriessen at thehealthagency.com
Wed Feb 2 03:15:06 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zope2.12-py2.6 slave-osx
- Next message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.1-py2.6 slave-ubuntu32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope Buildbot / zope2.13-py2.6 slave-osx
    Build: http://dev.thehealthagency.com/buildbot/builders/zope2.13-py2.6%20slave-osx/builds/121

    Build Reason: The Periodic scheduler named 'Periodic scheduler for zope2.13-py2.6' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://dev.thehealthagency.com/buildbot/

- Previous message: [Zope-tests] OK : Zope Buildbot / zope2.12-py2.6 slave-osx
- Next message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.1-py2.6 slave-ubuntu32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list